#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>

using namespace std;

class point {
 public:
  int x;
  int y;
  
  point(int _x=0, int _y=0) { x=_x; y=_y; }
  bool operator> (point) const;
  bool operator< (point) const;
  
  bool operator== (point a) const{
    return (a==a.x && y==a.y);
  }
  
};

int cp(point a, point b, point c) {
  int Ax = b.x-a.x;
  int Ay = b.y-a.y;
  int Bx = c.x-a.x;
  int By = c.y-a.y;
  
  return Ax*By - Ay*Bx;
}

double mcosine(point a) {
  if(a.x == a.y && a.x == 0)
    return 0;
  
  double res = a.x / sqrt(a.x*a.x + a.y*a.y);
  
  if(a.y<0) {
    if(a.x<0)
      res-=1.0;
    else
      res-=3.0;
  }
  
  return res;
}

bool point::operator> (point a) const{
  return mcosine(*this) > mcosine(a);
}

bool point::operator< (point a) const{
  return mcosine(*this) < mcosine(a);
}

struct triangle{
  point a, b, c;
  triangle(point _a = point(), point _b = point(), point _c = point()) {
    if(_a > _b)
      swap(_a, _b);
    if(_a > _c)
      swap(_a, _c);
    if(_b > _c)
      swap(_b, _c);
    
    a=_a;
    b=_b;
    c=_c;
  }
  
  bool operator< (triangle t) const{
    return abs(cp(a,b,c)) < abs(cp(t.a, t.b, t.c));
  }
  
  bool inner (triangle t) {
    bool res = true;
    
     int x;    
//    x = cp(a, b, t.a);
//    res &= (((x<0) == (cp(a, b, t.b)<0)) && ((x<0) == (cp(a,b,t.c)<0)));
    
//    cout<<"ab"<<endl;
//    cout<<x<<" "<<cp(a, b, t.b)<<" "<<cp(a,b,t.c)<<endl;
    
//    x = cp(c, b, t.a);
//    res &= (((x<0) == (cp(c, b, t.b)<0)) && ((x<0) == (cp(c,b,t.c)<0)));
    
//    cout<<"cb"<<endl;
//    cout<<x<<" "<<cp(c, b, t.b)<<" "<<cp(c,b,t.c)<<endl;
    
//    x = cp(c, a, t.a);
//    res &= (((x<0) == (cp(c, a, t.b)<0)) && ((x<0) == (cp(c,a,t.c)<0)));
    
//    cout<<"ca"<<endl;
//    cout<<x<<" "<<cp(c, a, t.b)<<" "<<cp(c,a,t.c)<<endl;
    
    x = cp(a, b, c);
    res &= (((x<0) == (cp(a, b, t.b)<0)) && ((x<0) == (cp(a,b,t.c)<0)) && ((x<0) == (cp(a,b,t.a)<0)));
    
    x = cp(c, b, a);
    res &= (((x<0) == (cp(c, b, t.b)<0)) && ((x<0) == (cp(c,b,t.c)<0)) && ((x<0) == (cp(c,b,t.a)<0)));
    
    x = cp(c, a, b);
    res &= (((x<0) == (cp(c, a, t.b)<0)) && ((x<0) == (cp(c,a,t.c)<0)) && ((x<0) == (cp(c,a,t.a)<0)));
    
//    cout<<"abc"<<endl;
//    cout<<x<<" "<<cp(a, b, t.b)<<" "<<cp(a,b,t.c)<<" "<<cp(a,b,t.a)<<endl;
    
    return res;
  }
};

int in[1001];

int main() {
    
    int n;
    vector<triangle> t;
    
    cin>>n;
    
    for(int i=0;i<n; i++) {
      point a,b,c;
      cin>>a.x>>a.y
         >>b.x>>b.y
         >>c.x>>c.y;
      
      t.push_back(triangle(a,b,c));
    }
    
    sort(t.begin(), t.end(), less<triangle>());
    
    
    int maxt=0;
       
    for(int i=1; i<n; i++) {
      for(int j=0; j<i; j++) {
//        cout<<i<<" "<<j<<":\n";
        if(t[i].inner(t[j]))
          in[i] = max(in[j]+1, in[i]);
      }
      maxt = max(in[i], maxt);
    }
    
    cout<<maxt+1<<endl;
          
    return 0;   
}
